/*
 ***********************************************************************
 *                                                                     *
 * Program to control ICOM radios                                      *
 *                                                                     *
 * Header file                                                         *
 *                                                                     *
 ***********************************************************************
 */

#define TRUE 1			/* veracity */
#define FALSE 0			/* tenacity */
#define BMAX 20			/* max packet buffer size */
#define SMAX 80			/* max string buffer size */

/*
 * Debug flags (debug)
 */
#define X_TRACE	0x01		/* trace packets */
#define X_ERMSG	0x02		/* bus error messages */

/*
 * Control flags (flags)
 */
#define F_RCV	0x0001		/* 0: transceiver, 1: receiver */
#define F_VFO	0x0002		/* does not have VFO (R7000 only) */
#define F_MHZ	0x0004		/* 0: kHz, 1: MHz */
#define F_OFFSET 0x0010		/* has duplex offset (VHF/UHF
				 * transceivers only) */
#define F_SCAN	0x0008		/* has scan (275/375/575/775 only) */
#define F_MEM	0x0010		/* requires explicit mode (775) */

/*
 * CI-V frame codes
 */
#define PR	0xfe		/* preamble */
#define TX	0xe0		/* controller address */
#define FI	0xfd		/* end of message */
#define ACK	0xfb		/* controller normal reply */
#define NAK	0xfa		/* controller error reply */

/*
 * CI-V controller commands
 */
#define V_FREQT	0x00		/* freq set (transceive) */
#define V_MODET	0x01		/* set mode (transceive) */
#define V_RBAND	0x02		/* read band edge */
#define V_RFREQ	0x03		/* read frequency */
#define V_RMODE	0x04		/* read mode */
#define V_SFREQ	0x05		/* set frequency */
#define V_SMODE	0x06		/* set mode */
#define V_SVFO	0x07		/* set vfo */
#define V_SMEM	0x08		/* set channel */
#define V_WRITE	0x09		/* write channel */
#define V_VFOM	0x0a		/* memory -> vfo */
#define V_CLEAR	0x0b		/* clear channel */
#define V_ROFFS	0x0c		/* read tx offset (VHF/UHF only) */
#define V_SOFFS	0x0d		/* write tx offset (VHF/UHF only) */
#define V_SCAN	0x0e		/* scan control */
#define V_SPLIT	0x0f		/* split control (775 only) */
#define V_TUNE	0x10		/* set tuning step (775 only) */
#define V_SANT	0x12		/* select antenna (775 only) */
#define V_ASCII	0x17		/* send CW message (775 only) */
 
/*
 * Set vfo (V_SVFO) subcommands
 */
#define V_XCHNG	0xb0		/* main <-> sub */
#define V_EQUAL	0xb1		/* main -> sub */
#define V_DWOFF	0xc0		/* dualwatch off */
#define V_DWON	0xc1		/* dualwatch on */
 
/*
 * Scan control (V_SCAN) and split control (V_SPLIT) subcommands
 */
#define S_OFF	0x00		/* scan stop/split off */
#define S_ON	0x01		/* scan start/split on */

/*
 * Radio control structure
 */
struct icom {
	char name[30];		/* radio name */
	int ident;		/* bus address */
	int maxch;		/* max memory channel */
	int flags;		/* type bits */
	int mchan;		/* memory channel */
	int mode;		/* VFO mode */
	struct modestruct *modetab; /* mode decode table */
	double vfo;		/* vfo frequency (Hz) */
	double sub;		/* sub vfo frequency (Hz) */
	double duplex;		/* duplex offset (Hz) */
	double offset;		/* frequency offset (Hz) */
	double step;		/* tuning step (Hz) */
	double uband;		/* upper band edge (Hz) */
	double lband;		/* lower band edge (Hz) */
	};

/*
 * Mode decode structure
 */
struct modestruct {
	char name[10];		/* mode name */
	int mode;		/* mode code */
	};
